@@ -1,44 +1,5 @@
 package Class::Inspector;
 
-=pod
-
-=head1 NAME
-
-Class::Inspector - Get information about a class and its structure
-
-=head1 SYNOPSIS
-
-  use Class::Inspector;
-  
-  # Is a class installed and/or loaded
-  Class::Inspector->installed( 'Foo::Class' );
-  Class::Inspector->loaded( 'Foo::Class' );
-  
-  # Filename related information
-  Class::Inspector->filename( 'Foo::Class' );
-  Class::Inspector->resolved_filename( 'Foo::Class' );
-  
-  # Get subroutine related information
-  Class::Inspector->functions( 'Foo::Class' );
-  Class::Inspector->function_refs( 'Foo::Class' );
-  Class::Inspector->function_exists( 'Foo::Class', 'bar' );
-  Class::Inspector->methods( 'Foo::Class', 'full', 'public' );
-  
-  # Find all loaded subclasses or something
-  Class::Inspector->subclasses( 'Foo::Class' );
-
-=head1 DESCRIPTION
-
-Class::Inspector allows you to get information about a loaded class. Most or
-all of this information can be found in other ways, but they aren't always
-very friendly, and usually involve a relatively high level of Perl wizardry,
-or strange and unusual looking code. Class::Inspector attempts to provide 
-an easier, more friendly interface to this information.
-
-=head1 METHODS
-
-=cut
-
 use 5.006;
 # We don't want to use strict refs anywhere in this module, since we do a
 # lot of things in here that aren't strict refs friendly.
@@ -46,60 +7,59 @@ use strict qw{vars subs};
 use warnings;
 use File::Spec ();
 
-# Globals
-use vars qw{$VERSION $RE_IDENTIFIER $RE_CLASS $UNIX};
+# ABSTRACT: Get information about a class and its structure
+our $VERSION = '1.33_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
+
+
+# If Unicode is available, enable it so that the
+# pattern matches below match unicode method names.
+# We can safely ignore any failure here.
 BEGIN {
-  $VERSION = '1.29_02';
-
-  # If Unicode is available, enable it so that the
-  # pattern matches below match unicode method names.
-  # We can safely ignore any failure here.
-  SCOPE: {
-    local $@;
-    eval "require utf8; utf8->import";
-  }
-
-  # Predefine some regexs
-  $RE_IDENTIFIER = qr/\A[^\W\d]\w*\z/s;
-  $RE_CLASS      = qr/\A[^\W\d]\w*(?:(?:\'|::)\w+)*\z/s;
-
-  # Are we on something Unix-like?
-  $UNIX  = !! ( $File::Spec::ISA[0] eq 'File::Spec::Unix'  );
+  local $@;
+  eval "require utf8; utf8->import";
 }
 
+# Predefine some regexs
+our $RE_IDENTIFIER = qr/\A[^\W\d]\w*\z/s;
+our $RE_CLASS      = qr/\A[^\W\d]\w*(?:(?:\'|::)\w+)*\z/s;
 
-
+# Are we on something Unix-like?
+our $UNIX  = !! ( $File::Spec::ISA[0] eq 'File::Spec::Unix'  );
 
 
 #####################################################################
 # Basic Methods
 
-=pod
-
-=head2 installed $class
-
-The C<installed> static method tries to determine if a class is installed
-on the machine, or at least available to Perl. It does this by wrapping
-around C<resolved_filename>.
-
-Returns true if installed/available, false if the class is not installed,
-or C<undef> if the class name is invalid.
-
-=cut
 
 sub _resolved_inc_handler {
   my $class    = shift;
   my $filename = $class->_inc_filename(shift) or return undef;
-  
+
   foreach my $inc ( @INC ) {
-    if(ref $inc eq 'CODE') {
+    my $ref = ref $inc;
+    if($ref eq 'CODE') {
       my @ret = $inc->($inc, $filename);
+      if(@ret == 1 && ! defined $ret[0]) {
+        # do nothing.
+      } elsif(@ret) {
+        return 1;
+      }
+    }
+    elsif($ref eq 'ARRAY' && ref($inc->[0]) eq 'CODE') {
+      my @ret = $inc->[0]->($inc, $filename);
+      if(@ret) {
+        return 1;
+      }
+    }
+    elsif($ref && eval { $inc->can('INC') }) {
+      my @ret = $inc->INC($filename);
       if(@ret) {
         return 1;
       }
     }
   }
-  
+
   '';
 }
 
@@ -108,24 +68,6 @@ sub installed {
   !! ($class->loaded_filename($_[0]) or $class->resolved_filename($_[0]) or $class->_resolved_inc_handler($_[0]));
 }
 
-=pod
-
-=head2 loaded $class
-
-The C<loaded> static method tries to determine if a class is loaded by
-looking for symbol table entries.
-
-This method it uses to determine this will work even if the class does not
-have its own file, but is contained inside a single file with multiple
-classes in it. Even in the case of some sort of run-time loading class
-being used, these typically leave some trace in the symbol table, so an
-L<Autoload> or L<Class::Autouse>-based class should correctly appear
-loaded.
-
-Returns true if the class is loaded, false if not, or C<undef> if the
-class name is invalid.
-
-=cut
 
 sub loaded {
   my $class = shift;
@@ -156,23 +98,6 @@ sub _loaded {
   '';
 }
 
-=pod
-
-=head2 filename $class
-
-For a given class, returns the base filename for the class. This will NOT
-be a fully resolved filename, just the part of the filename BELOW the
-C<@INC> entry.
-
-  print Class->filename( 'Foo::Bar' );
-  > Foo/Bar.pm
-
-This filename will be returned with the right separator for the local
-platform, and should work on all platforms.
-
-Returns the filename on success or C<undef> if the class name is invalid.
-
-=cut
 
 sub filename {
   my $class = shift;
@@ -180,25 +105,6 @@ sub filename {
   File::Spec->catfile( split /(?:\'|::)/, $name ) . '.pm';
 }
 
-=pod
-
-=head2 resolved_filename $class, @try_first
-
-For a given class, the C<resolved_filename> static method returns the fully
-resolved filename for a class. That is, the file that the class would be
-loaded from.
-
-This is not necessarily the file that the class WAS loaded from, as the
-value returned is determined each time it runs, and the C<@INC> include
-path may change.
-
-To get the actual file for a loaded class, see the C<loaded_filename>
-method.
-
-Returns the filename for the class, or C<undef> if the class name is
-invalid.
-
-=cut
 
 sub resolved_filename {
   my $class     = shift;
@@ -216,18 +122,6 @@ sub resolved_filename {
   '';
 }
 
-=pod
-
-=head2 loaded_filename $class
-
-For a given loaded class, the C<loaded_filename> static method determines
-(via the C<%INC> hash) the name of the file that it was originally loaded
-from.
-
-Returns a resolved file path, or false if the class did not have it's own
-file.
-
-=cut
 
 sub loaded_filename {
   my $class    = shift;
@@ -242,19 +136,6 @@ sub loaded_filename {
 #####################################################################
 # Sub Related Methods
 
-=pod
-
-=head2 functions $class
-
-For a loaded class, the C<functions> static method returns a list of the
-names of all the functions in the classes immediate namespace.
-
-Note that this is not the METHODS of the class, just the functions.
-
-Returns a reference to an array of the function names on success, or C<undef>
-if the class name is invalid or the class is not loaded.
-
-=cut
 
 sub functions {
   my $class = shift;
@@ -268,19 +149,6 @@ sub functions {
   \@functions;
 }
 
-=pod
-
-=head2 function_refs $class
-
-For a loaded class, the C<function_refs> static method returns references to
-all the functions in the classes immediate namespace.
-
-Note that this is not the METHODS of the class, just the functions.
-
-Returns a reference to an array of C<CODE> refs of the functions on
-success, or C<undef> if the class is not loaded.
-
-=cut
 
 sub function_refs {
   my $class = shift;
@@ -296,20 +164,6 @@ sub function_refs {
   \@functions;
 }
 
-=pod
-
-=head2 function_exists $class, $function
-
-Given a class and function name the C<function_exists> static method will
-check to see if the function exists in the class.
-
-Note that this is as a function, not as a method. To see if a method
-exists for a class, use the C<can> method for any class or object.
-
-Returns true if the function exists, false if not, or C<undef> if the
-class or function name are invalid, or the class is not loaded.
-
-=cut
 
 sub function_exists {
   my $class    = shift;
@@ -323,72 +177,6 @@ sub function_exists {
   defined &{"${name}::$function"};
 }
 
-=pod
-
-=head2 methods $class, @options
-
-For a given class name, the C<methods> static method will returns ALL
-the methods available to that class. This includes all methods available
-from every class up the class' C<@ISA> tree.
-
-Returns a reference to an array of the names of all the available methods
-on success, or C<undef> if the class name is invalid or the class is not
-loaded.
-
-A number of options are available to the C<methods> method that will alter
-the results returned. These should be listed after the class name, in any
-order.
-
-  # Only get public methods
-  my $method = Class::Inspector->methods( 'My::Class', 'public' );
-
-=over 4
-
-=item public
-
-The C<public> option will return only 'public' methods, as defined by the Perl
-convention of prepending an underscore to any 'private' methods. The C<public> 
-option will effectively remove any methods that start with an underscore.
-
-=item private
-
-The C<private> options will return only 'private' methods, as defined by the
-Perl convention of prepending an underscore to an private methods. The
-C<private> option will effectively remove an method that do not start with an
-underscore.
-
-B<Note: The C<public> and C<private> options are mutually exclusive>
-
-=item full
-
-C<methods> normally returns just the method name. Supplying the C<full> option
-will cause the methods to be returned as the full names. That is, instead of
-returning C<[ 'method1', 'method2', 'method3' ]>, you would instead get
-C<[ 'Class::method1', 'AnotherClass::method2', 'Class::method3' ]>.
-
-=item expanded
-
-The C<expanded> option will cause a lot more information about method to be 
-returned. Instead of just the method name, you will instead get an array
-reference containing the method name as a single combined name, ala C<full>,
-the separate class and method, and a CODE ref to the actual function ( if
-available ). Please note that the function reference is not guaranteed to 
-be available. C<Class::Inspector> is intended at some later time, to work 
-with modules that have some kind of common run-time loader in place ( e.g
-C<Autoloader> or C<Class::Autouse> for example.
-
-The response from C<methods( 'Class', 'expanded' )> would look something like
-the following.
-
-  [
-    [ 'Class::method1',   'Class',   'method1', \&Class::method1   ],
-    [ 'Another::method2', 'Another', 'method2', \&Another::method2 ],
-    [ 'Foo::bar',         'Foo',     'bar',     \&Foo::bar         ],
-  ]
-
-=back
-
-=cut
 
 sub methods {
   my $class     = shift;
@@ -446,7 +234,7 @@ sub methods {
   foreach my $namespace ( @path ) {
     my @functions = grep { ! $methods{$_} }
       grep { /$RE_IDENTIFIER/o }
-      grep { defined &{"${namespace}::$_"} } 
+      grep { defined &{"${namespace}::$_"} }
       keys %{"${namespace}::"};
     foreach ( @functions ) {
       $methods{$_} = $namespace;
@@ -460,8 +248,8 @@ sub methods {
 
   # Return in the correct format
   @methodlist = map { "$methods{$_}::$_" } @methodlist if $options{full};
-  @methodlist = map { 
-    [ "$methods{$_}::$_", $methods{$_}, $_, \&{"$methods{$_}::$_"} ] 
+  @methodlist = map {
+    [ "$methods{$_}::$_", $methods{$_}, $_, \&{"$methods{$_}::$_"} ]
     } @methodlist if $options{expanded};
 
   \@methodlist;
@@ -474,22 +262,6 @@ sub methods {
 #####################################################################
 # Search Methods
 
-=pod
-
-=head2 subclasses $class
-
-The C<subclasses> static method will search then entire namespace (and thus
-B<all> currently loaded classes) to find all classes that are subclasses
-of the class provided as a the parameter.
-
-The actual test will be done by calling C<isa> on the class as a static
-method. (i.e. C<My::Class-E<gt>isa($class)>.
-
-Returns a reference to a list of the loaded classes that match the class
-provided, or false is none match, or C<undef> if the class name provided
-is invalid.
-
-=cut
 
 sub subclasses {
   my $class = shift;
@@ -563,7 +335,7 @@ sub recursive_children {
   my $name     = $class->_class(shift) or return ();
   my @children = ( $name );
 
-  # Do the search using a nicer, more memory efficient 
+  # Do the search using a nicer, more memory efficient
   # variant of actual recursion.
   my $i = 0;
   no strict 'refs';
@@ -623,38 +395,265 @@ sub _inc_to_local {
 
 1;
 
+__END__
+
 =pod
 
-=head1 SUPPORT
+=encoding UTF-8
 
-Bugs should be reported via the CPAN bug tracker
+=head1 NAME
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Class-Inspector>
+Class::Inspector - Get information about a class and its structure
 
-For other issues, or commercial enhancement or support, contact the author.
+=head1 VERSION
 
-=head1 AUTHOR
+version 1.33_01
 
-The current maintainer is:
+=head1 SYNOPSIS
 
-Graham Ollis E<lt>plicease@cpan.orgE<gt>
+  use Class::Inspector;
+  
+  # Is a class installed and/or loaded
+  Class::Inspector->installed( 'Foo::Class' );
+  Class::Inspector->loaded( 'Foo::Class' );
+  
+  # Filename related information
+  Class::Inspector->filename( 'Foo::Class' );
+  Class::Inspector->resolved_filename( 'Foo::Class' );
+  
+  # Get subroutine related information
+  Class::Inspector->functions( 'Foo::Class' );
+  Class::Inspector->function_refs( 'Foo::Class' );
+  Class::Inspector->function_exists( 'Foo::Class', 'bar' );
+  Class::Inspector->methods( 'Foo::Class', 'full', 'public' );
+  
+  # Find all loaded subclasses or something
+  Class::Inspector->subclasses( 'Foo::Class' );
 
-The original author is:
+=head1 DESCRIPTION
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Class::Inspector allows you to get information about a loaded class. Most or
+all of this information can be found in other ways, but they aren't always
+very friendly, and usually involve a relatively high level of Perl wizardry,
+or strange and unusual looking code. Class::Inspector attempts to provide
+an easier, more friendly interface to this information.
+
+=head1 METHODS
+
+=head2 installed
+
+ my $bool = Class::Inspector->installed($class);
+
+The C<installed> static method tries to determine if a class is installed
+on the machine, or at least available to Perl. It does this by wrapping
+around C<resolved_filename>.
+
+Returns true if installed/available, false if the class is not installed,
+or C<undef> if the class name is invalid.
+
+=head2 loaded
+
+ my $bool = Class::Inspector->loaded($class);
+
+The C<loaded> static method tries to determine if a class is loaded by
+looking for symbol table entries.
+
+This method it uses to determine this will work even if the class does not
+have its own file, but is contained inside a single file with multiple
+classes in it. Even in the case of some sort of run-time loading class
+being used, these typically leave some trace in the symbol table, so an
+L<Autoload> or L<Class::Autouse>-based class should correctly appear
+loaded.
+
+Returns true if the class is loaded, false if not, or C<undef> if the
+class name is invalid.
+
+=head2 filename
+
+ my $filename = Class::Inspector->filename($class);
+
+For a given class, returns the base filename for the class. This will NOT
+be a fully resolved filename, just the part of the filename BELOW the
+C<@INC> entry.
+
+  print Class->filename( 'Foo::Bar' );
+  > Foo/Bar.pm
+
+This filename will be returned with the right separator for the local
+platform, and should work on all platforms.
+
+Returns the filename on success or C<undef> if the class name is invalid.
+
+=head2 resolved_filename
+
+ my $filename = Class::Inspector->resolved_filename($class);
+ my $filename = Class::Inspector->resolved_filename($class, @try_first);
+
+For a given class, the C<resolved_filename> static method returns the fully
+resolved filename for a class. That is, the file that the class would be
+loaded from.
+
+This is not necessarily the file that the class WAS loaded from, as the
+value returned is determined each time it runs, and the C<@INC> include
+path may change.
+
+To get the actual file for a loaded class, see the C<loaded_filename>
+method.
+
+Returns the filename for the class, or C<undef> if the class name is
+invalid.
+
+=head2 loaded_filename
+
+ my $filename = Class::Inspector->loaded_filename($class);
+
+For a given loaded class, the C<loaded_filename> static method determines
+(via the C<%INC> hash) the name of the file that it was originally loaded
+from.
+
+Returns a resolved file path, or false if the class did not have it's own
+file.
+
+=head2 functions
+
+ my $arrayref = Class::Inspector->functions($class);
+
+For a loaded class, the C<functions> static method returns a list of the
+names of all the functions in the classes immediate namespace.
+
+Note that this is not the METHODS of the class, just the functions.
+
+Returns a reference to an array of the function names on success, or C<undef>
+if the class name is invalid or the class is not loaded.
+
+=head2 function_refs
+
+ my $arrayref = Class::Inspector->function_refs($class);
+
+For a loaded class, the C<function_refs> static method returns references to
+all the functions in the classes immediate namespace.
+
+Note that this is not the METHODS of the class, just the functions.
+
+Returns a reference to an array of C<CODE> refs of the functions on
+success, or C<undef> if the class is not loaded.
+
+=head2 function_exists
+
+ my $bool = Class::Inspector->function_exists($class, $functon);
+
+Given a class and function name the C<function_exists> static method will
+check to see if the function exists in the class.
+
+Note that this is as a function, not as a method. To see if a method
+exists for a class, use the C<can> method for any class or object.
+
+Returns true if the function exists, false if not, or C<undef> if the
+class or function name are invalid, or the class is not loaded.
+
+=head2 methods
+
+ my $arrayref = Class::Inspector->methods($class, @options);
+
+For a given class name, the C<methods> static method will returns ALL
+the methods available to that class. This includes all methods available
+from every class up the class' C<@ISA> tree.
+
+Returns a reference to an array of the names of all the available methods
+on success, or C<undef> if the class name is invalid or the class is not
+loaded.
+
+A number of options are available to the C<methods> method that will alter
+the results returned. These should be listed after the class name, in any
+order.
+
+  # Only get public methods
+  my $method = Class::Inspector->methods( 'My::Class', 'public' );
+
+=over 4
+
+=item public
+
+The C<public> option will return only 'public' methods, as defined by the Perl
+convention of prepending an underscore to any 'private' methods. The C<public>
+option will effectively remove any methods that start with an underscore.
+
+=item private
+
+The C<private> options will return only 'private' methods, as defined by the
+Perl convention of prepending an underscore to an private methods. The
+C<private> option will effectively remove an method that do not start with an
+underscore.
+
+B<Note: The C<public> and C<private> options are mutually exclusive>
+
+=item full
+
+C<methods> normally returns just the method name. Supplying the C<full> option
+will cause the methods to be returned as the full names. That is, instead of
+returning C<[ 'method1', 'method2', 'method3' ]>, you would instead get
+C<[ 'Class::method1', 'AnotherClass::method2', 'Class::method3' ]>.
+
+=item expanded
+
+The C<expanded> option will cause a lot more information about method to be
+returned. Instead of just the method name, you will instead get an array
+reference containing the method name as a single combined name, a la C<full>,
+the separate class and method, and a CODE ref to the actual function ( if
+available ). Please note that the function reference is not guaranteed to
+be available. C<Class::Inspector> is intended at some later time, to work
+with modules that have some kind of common run-time loader in place ( e.g
+C<Autoloader> or C<Class::Autouse> for example.
+
+The response from C<methods( 'Class', 'expanded' )> would look something like
+the following.
+
+  [
+    [ 'Class::method1',   'Class',   'method1', \&Class::method1   ],
+    [ 'Another::method2', 'Another', 'method2', \&Another::method2 ],
+    [ 'Foo::bar',         'Foo',     'bar',     \&Foo::bar         ],
+  ]
+
+=back
+
+=head2 subclasses
+
+ my $arrayref = Class::Inspector->subclasses($class);
+
+The C<subclasses> static method will search then entire namespace (and thus
+B<all> currently loaded classes) to find all classes that are subclasses
+of the class provided as a the parameter.
+
+The actual test will be done by calling C<isa> on the class as a static
+method. (i.e. C<My::Class-E<gt>isa($class)>.
+
+Returns a reference to a list of the loaded classes that match the class
+provided, or false is none match, or C<undef> if the class name provided
+is invalid.
 
 =head1 SEE ALSO
 
-L<http://ali.as/>, L<Class::Handle>
+L<http://ali.as/>, L<Class::Handle>, L<Class::Inspector::Functions>
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2002 - 2012 Adam Kennedy.
+Original author: Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+Contributors:
+
+Tom Wyant
+
+Steffen Müller
+
+Kivanc Yazan (KYZN)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002-2019 by Adam Kennedy.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
