@@ -6,13 +6,15 @@ use warnings;
 use Exporter         ();
 use Class::Inspector ();
 
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
+# ABSTRACT: Get information about a class and its structure
+our $VERSION = '1.33_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
+
 BEGIN {
-  $VERSION = '1.29_02';
-  @ISA     = 'Exporter';
+  our @ISA     = 'Exporter';
 
 
-  @EXPORT = qw(
+  our @EXPORT = qw(
     installed
     loaded
 
@@ -23,7 +25,7 @@ BEGIN {
     subclasses
   );
 
-  @EXPORT_OK = qw(
+  our @EXPORT_OK = qw(
     resolved_filename
     loaded_filename
 
@@ -33,7 +35,7 @@ BEGIN {
     #children
     #recursive_children
 
-  %EXPORT_TAGS = ( ALL => [ @EXPORT_OK, @EXPORT ] );
+  our %EXPORT_TAGS = ( ALL => [ @EXPORT_OK, @EXPORT ] );
 
   foreach my $meth (@EXPORT, @EXPORT_OK) {
       my $sub = Class::Inspector->can($meth);
@@ -49,10 +51,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Class::Inspector::Functions - Get information about a class and its structure
 
+=head1 VERSION
+
+version 1.33_01
+
 =head1 SYNOPSIS
 
   use Class::Inspector::Functions;
@@ -102,34 +110,29 @@ The following functions are exported only by request.
 
 All the functions may be imported using the C<:ALL> tag.
 
-=head1 SUPPORT
+=head1 SEE ALSO
 
-Bugs should be reported via the CPAN bug tracker
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Class-Inspector>
-
-For other issues, or commercial enhancement or support, contact the author.
+L<http://ali.as/>, L<Class::Handle>, L<Class::Inspector>
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Original author: Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-=head1 SEE ALSO
+Contributors:
 
-L<http://ali.as/>, L<Class::Handle>
+Tom Wyant
 
-=head1 COPYRIGHT
+Steffen Müller
 
-Copyright 2002 - 2012 Adam Kennedy.
+Kivanc Yazan (KYZN)
 
-Class::Inspector::Functions copyright 2008 - 2009 Steffen Mueller.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+This software is copyright (c) 2002-2019 by Adam Kennedy.
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
